/**
 * connection.js
 *
 * Set up the connection for your remote data source.
 * You must set either "url" or "toUrl".
 * Use "url" if the url is static or can be generated by substituting context vars.
 * Use "toUrl" if you need to dynamically create the url based on subjects and aspects.
 *
 * DO NOT modify the function signature.
 * DO NOT import or require any other modules.
 * DO NOT modify the module.exports (for testing).
 */

module.exports = {

  /**
   * Url (optional)
   *
   * Specify a url string to use for collection.
   * You can use context variables with {{var}}.
   */
  url: 'https://{{baseUrl}}?expression={{window}}:subjects:all:tests:all',

  /**
   * Headers (optional)
   *
   * Specify the HTTP headers to include in the request.
   * You can use context variables with {{var}}.
   */
  headers: {
    Accept: '{{type}}/{{subtype}}',
    Authorization: '{{token}}',
  },

  /**
   * ContextDefinition (optional)
   *
   * Define context variables that the connection relies on here.
   * The values that get passed in to the connection will be assigned in the
   * Sample Generator.
   * You can also specify a default value here, to be used if "required" is
   * false and no value is set.
   * If the value is sensitive and must be stored encrypted, set "encrypted: true".
   */
  contextDefinition: {
    baseUrl: {
      description: 'the base url to add the params to',
      required: true,
      encrypted: false,
    },
    window: {
      description: 'the window value to be set in the url',
      required: false,
      encrypted: false,
      default: '-15m',
    },
    type: {
      description: 'The content-type type',
      required: false,
      encrypted: false,
      default: 'text',
    },
    subtype: {
      description: 'The content-type subtype',
      required: false,
      encrypted: false,
      default: 'plain',
    },
    token: {
      description: 'The api token for the remote data source',
      required: true,
      encrypted: true,
    },
  },

};
