/**
 * connection.js
 *
 * Set up the connection for your remote data source.
 * You must set either "url" or "toUrl".
 * Use "url" if the url is static or can be generated by substituting context vars.
 * Use "toUrl" if you need to dynamically create the url based on subjects and aspects.
 *
 * DO NOT modify the function signature.
 * DO NOT import or require any other modules.
 * DO NOT modify the module.exports (for testing).
 */

module.exports = {

  /**
   * Url (optional)
   *
   * Specify a url string to use for collection.
   * You can use context variables with {{var}}.
   */
  url: 'https://{{baseTrustUrl}}?expression',

  /**
   * Headers (optional)
   *
   * Specify the HTTP headers to include in the request.
   * You can use context variables with {{var}}.
   */
  headers: {
    Accept: 'text/html',
  },

  /**
   * ContextDefinition (optional)
   *
   * Define context variables that the transform function relies on here.
   * The values that get passed in to the transform will be assigned in the
   * Sample Generator. You can also specify a default value here, to be used if
   * "required" is false and no value is set.
   */
  contextDefinition: {
    errorValue: {
      required: false,
      default: '-1',
      description: 'An error sample\'s value, e.g. \'-1\'.',
    },
    baseTrustUrl: {
      required: true,
      description: 'The base url of your Trust1 API endpoint, e.g. \'https://api.status.salesforce.com\'.',
    },
    statusLinkUrl: {
      required: true,
      description: 'The base url of your Trust1 endpoint for a sample\'s related links, e.g. \'http://status.salesforce.com/status/\'.',
    },
    statusMap: {
      required: false,
      default: {
        OK: {
          value: '0'
        },
        INFORMATIONAL_NONCORE: {
          value: '1'
        },
        MAINTENANCE_NONCORE: {
          value: '1'
        },
        MINOR_INCIDENT_NONCORE: {
          value: '2'
        },
        MAJOR_INCIDENT_NONCORE: {
          value: '3'
        },
        INFORMATIONAL_CORE: {
          value: '1',
          messageCode: 'CORE'
        },
        MAINTENANCE_CORE: {
          value: '1',
          messageCode: 'CORE'
        },
        MINOR_INCIDENT_CORE: {
          value: '2',
          messageCode: 'CORE'
        },
        MAJOR_INCIDENT_CORE: {
          value: '3',
          messageCode: 'CORE'
        }
      },
      description: 'An object which maps each Trust1 status enum value to a sample value, messageCode and messageBody.',
    },
  },

};
